/// <reference types="react" />
export declare const useForm: <TFormValues extends IBaseFormValues>(props: {
    initialValues: TFormValues;
    validate?: ValidateFormFn<TFormValues> | undefined;
    onSubmit?: OnSubmitFormFn<TFormValues> | undefined;
}) => IHookedForm<TFormValues>;
export interface IHookedForm<TValues extends IBaseFormValues> {
    values: TValues;
    touchedFields: TouchedMap<TValues>;
    submitting: boolean;
    errors: ErrorMap<TValues>;
    setValue(key: keyof TValues, value: BaseValue): void;
    setTouch(key: keyof TValues, value: boolean): void;
    handleSubmit(e: React.FormEvent): void;
}
export declare type ErrorMap<KeyValueMap> = Partial<{
    [key in keyof KeyValueMap]: string;
}>;
export declare type TouchedMap<KeyValueMap> = Partial<{
    [key in keyof KeyValueMap]: boolean;
}>;
export declare type OnSubmitFormFn<TFormValues> = (values: TFormValues) => ErrorMap<TFormValues> | Promise<ErrorMap<TFormValues>>;
export declare type ValidateFormFn<TFormValues> = (values: TFormValues) => ErrorMap<TFormValues>;
export interface IBaseFormValues {
    [key: string]: BaseValue;
}
declare type BaseValue = string | number | undefined;
export {};
